@@ -75,6 +75,7 @@ private Q_SLOTS:
     void folderScanCompleted(Folder*);
     void mapChanged(const Folder*);
     void updateURL(const QUrl &);
+    void rescanSingleDir(const QUrl &);
 
 protected:
     void saveProperties(KConfigGroup&) override;
@@ -84,7 +85,7 @@ protected:
 private:
     void setupActions();
     bool closeUrl();
-    QString prettyUrl() const;
+    QString prettyUrl(const QUrl &url) const;
     void showSummary();
     bool start(const QUrl&);
 
