@@ -1,22 +1,8 @@
 /***********************************************************************
-* Copyright 2003-2004  Max Howell <max.howell@methylblue.com>
-* Copyright 2008-2009  Martin Sandsmark <martin.sandsmark@kde.org>
+* SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
+* SPDX-FileCopyrightText: 2008-2009 Martin Sandsmark <martin.sandsmark@kde.org>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License or (at your option) version 3 or any later version
-* accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy
-* defined in Section 14 of version 3 of the license.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 ***********************************************************************/
 
 #include "summaryWidget.h"
@@ -173,7 +159,7 @@ DiskList::DiskList()
         disk.mount = storage.rootPath();
         disk.name = storage.name();
         disk.size = storage.bytesTotal();
-        disk.free = storage.bytesFree();
+        disk.free = storage.bytesAvailable();
         disk.used = disk.size - disk.free;
 
         // if something is mounted over same path, last mounted point would be used since only it is currently reachable.
